/******************************************************************************
*                                  S.Hofmann                                  *
*                                mc_sho@gmx.de                                *
*******************************************************************************
*  $Source: $
*-----------------------------------------------------------------------------*
*  Datum der 1. Version  :  30.04.2008 22:16
*  Geraete Bezeichnung   :  AMOLED-Adapter
*-----------------------------------------------------------------------------*
*- $Id: $
*-----------------------------------------------------------------------------*
*
*	Headerfile
*	----------
*	AMOLED Controller S6E63D6
*
******************************************************************************/

#ifndef _S6E63D6_H_
#define _S6E63D6_H_

#include "types.h"

//-----------------------------------------------------------------------------
// Display Control
//-----------------------------------------------------------------------------
#define GOLED_NOP                           0x00

#define GOLED_DISPLAY_DUTY_CONTROL          0x01
//------------------------------------------------
#define GOLED_RGB INTERFACE CONTROL         0x02
//------------------------------------------------
#define GOLED_RM                            (1<<8)
#define GOLED_DM                            (1<<7)
#define GOLED_RIM0                          (1<<4)
#define GOLED_RIM1                          (1<<5)
#define GOLED_VSP_L                         (1<<3)
#define GOLED_VSP_H                         (1<<2)
#define GOLED_EPL                           (1<<1)
#define GOLED_DPL                           (1<<0)
#define GOLED_SYSTEM_INTERFACE              0x00                   // Internal clock operation
#define GOLED_RGB_INTERFACE                 (GOLED_RM | GOLED_DM)  // External clock operation
#define GOLED_RGB_18_BIT                    0x00
#define GOLED_RGB_16_BIT                    GOLED_RIM0
#define GOLED_RGB_6_BIT                     GOLED_RIM1
#define GOLED_RGB_SETTING_DISABLE           ( GOLED_RIM0 | GOLED_RIM1 )
//------------------------------------------------
#define GOLED_ENTRY_MODE                    0x03
//------------------------------------------------
#define GOLED_CLS                           (1<<15)
#define GOLED_MDT0                          (1<<13)
#define GOLED_MDT1                          (1<<14)
#define GOLED_BGR                           (1<<12)
#define GOLED_SS                            (1<<8)
#define GOLED_ID1                           (1<<5)
#define GOLED_ID0                           (1<<4)
#define GOLED_AM                            (1<<0)
//------------------------------------------------
#define GOLED_CLOCK_CONTROL                 0x04
//------------------------------------------------
#define GOLED_DCR0                          (1<<4)
#define GOLED_DCR1                          (1<<5)
#define GOLED_DOTCLK_4                      0x00    // default
#define GOLED_DOTCLK_8                      GOLED_DCR0
#define GOLED_DOTCLK_16                     GOLED_DCR1
#define GOLED_DOTCLK_32                     (GOLED_DCR0 | GOLED_DCR1)
//------------------------------------------------
#define GOLED_DISPLAY_CONTROL1              0x05
//------------------------------------------------
#define GOLED_DISP_ON                       (1<<0)
//------------------------------------------------
#define GOLED_DISPLAY_CONTROL2              0x06
#define GOLED_PANEL_IF_CONTROL1             0x06
#define GOLED_PANEL_IF_CONTROL2             0x08
#define GOLED_PANEL_IF_CONTROL3             0x09
#define GOLED_PANEL_IF_CONTROL4             0x0A

//-----------------------------------------------------------------------------
// Device Read
//-----------------------------------------------------------------------------
#define GOLED_DEVICE_CODE_READ              0x0F

//-----------------------------------------------------------------------------
// Power Control
//-----------------------------------------------------------------------------
//------------------------------------------------
#define GOLED_STAND_BY                      0x10
//------------------------------------------------
#define GOLED_STB                           (1<<0)
//------------------------------------------------
#define GOLED_POWER_GEN1                    0x12
#define GOLED_POWER_GEN2                    0x13
#define GOLED_POWER_STEP_UP_CONTROL1        0x14
#define GOLED_OSCILLATOR_CONTROL            0x18
#define GOLED_SOURCE_DRIVER_CONTROL         0x1A

//-----------------------------------------------------------------------------
// GRAM Access
//-----------------------------------------------------------------------------
#define GOLED_GRAM_ADDRESS_SET_LOW          0x20
#define GOLED_GRAM_ADDRESS_SET_HIGH         0x21
#define GOLED_GRAM_WRITE_READ               0x22

//-----------------------------------------------------------------------------
// I/F Control
//-----------------------------------------------------------------------------
#define GOLED_I_F_SELECT_18_16              0x23
#define GOLED_I_F_SELECT_9_8                0x24

//-----------------------------------------------------------------------------
// Position Control
//-----------------------------------------------------------------------------
#define GOLED_VERTICAL_SCROLL_CONTROL_SS    0x30
#define GOLED_VERTICAL_SCROLL_CONTROL_SE    0x31
#define GOLED_VERTICAL_SCROLL_CONTROL_2     0x32
#define GOLED_PARTIAL_SCREEN_DRIV_POS_SS    0x33
#define GOLED_PARTIAL_SCREEN_DRIV_POS_SE    0x34
#define GOLED_VERTICAL_RAM_ADDRESS_POS_VS   0x35
#define GOLED_VERTICAL_RAM_ADDRESS_POS_VE   0x36
#define GOLED_HORIZONTAL_RAM_ADR_POS        0x37

//-----------------------------------------------------------------------------
// MDDI I/F
//-----------------------------------------------------------------------------
#define GOLED_CLIENT_INITIATED_WAKE_UP      0x38
#define GOLED_MDDI_LINK_WAKE_UP_START_POS   0x39
#define GOLED_SUB_PANEL_CONTROL1            0x3A
#define GOLED_SUB_PANEL_CONTROL2            0x3B
#define GOLED_SUB_PANEL_CONTROL3            0x3C

//-----------------------------------------------------------------------------
// MTP Control
//-----------------------------------------------------------------------------
#define GOLED_TEST_KEY                      0x60
#define GOLED_MTP_SELECTION                 0x61
#define GOLED_MTP_REGISTER_SETTING_R        0x62
#define GOLED_MTP_REGISTER_SETTING_G        0x63
#define GOLED_MTP_REGISTER_SETTING_B        0x64
#define GOLED_MTP_REGISTER_OFFSET           0x65

//-----------------------------------------------------------------------------
// GPIO Control
//-----------------------------------------------------------------------------
#define GOLED_GPIO_VALUE                    0x66
#define GOLED_IN_OUTPUT_CONTROL             0x67
#define GOLED_GPIO_CLEAR                    0x68
#define GOLED_GPIO_INTERRUPT_ENABLE         0x69
#define GOLED_GPIO_POLARITY_SELECTION       0x6A

//-----------------------------------------------------------------------------
// Gamma Control
//-----------------------------------------------------------------------------
#define GOLED_GAMMA_TOP_BOTTO_CONTROL_R     0x70
#define GOLED_GAMMA_TOP_BOTTO_CONTROL_G     0x71
#define GOLED_GAMMA_TOP_BOTTO_CONTROL_B     0x72
#define GOLED_GAMMA_CONTROL_R_1_2           0x73
#define GOLED_GAMMA_CONTROL_R_3_4           0x74
#define GOLED_GAMMA_CONTROL_G_1_2           0x75
#define GOLED_GAMMA_CONTROL_G_3_4           0x76
#define GOLED_GAMMA_CONTROL_B_1_2           0x77
#define GOLED_GAMMA_CONTROL_B_3_4           0x78
#define GOLED_GAMMA_SELECT                  0x80

//-----------------------------------------------------------------------------
// Index
//-----------------------------------------------------------------------------
#define GOLED_RS                            (1<<1)
#define GOLED_RW                            (1<<0)
#define GOLED_ID                            (1<<2)

#define GOLED_DEVICE_ID                     0x70

//-----------------------------------------------------------------------------
// allg.
//-----------------------------------------------------------------------------
#define GOLED_LINE_ADR                      0x00100
#define GOLED_X                             320
#define GOLED_Y                             240
//-----------------------------------------------------------------------------
// function
//-----------------------------------------------------------------------------
void WriteIndex( WORD wData );
void WriteParameter( WORD wData );
WORD ReadS6E63D6( void );
void Goled_Adr( DWORD adr );
BYTE Goled_SetWindow( WORD bx, WORD by, WORD bLine, WORD bcol );
void WriteDisplay( WORD wColForeground, 
                   WORD wColBackground,  
                   WORD  wColumnCount,
                   WORD  wLineCount,
                   BYTE bx,
                   BYTE by,
                   const char *pArray );

#endif
