/*
**	Purpose:    SPI init, read & write routines without interrupt.
**              These routines works only as an SPI Master.
**
**  Version:    1.0.0, 29:th of July 1999
**
**  Author:     Lars Wictorsson
**              LAWICEL / SWEDEN
**              http://www.lawicel.com   lars@lawicel.com
**
**  History:    1999-07-29  Created
*/

#include "hw.h"
#include "spi.h"

/*
**  SpiInit() initializes the SPI as a master, enable it
**  and set it up as requested by parameter Controlregister.
**  See "spi.h" for availible parameter values, they could
**  be ORed together. See AVR SPI documentation for more 
**  detailed information.

void SpiInit(unsigned char ControlRegister)
{
    DDRB  |= 0xB0;  // Set SCK, MOSI & SS as outputs
    PORTB &= 0x5F;  // clear bits MOSI, & SCK

    SPCR = ControlRegister + SPE + MSTR;    // Write to control register.
}
*/
 //SPI initialize
// clock rate: 4000000hz
void spi_init(void)
{
 SPCR = SPI_S6E63D6; //setup SPI
 SPSR = 0x01; //setup SPI
}


/*
**  SpiWriteByte() writes a byte to the SPI and waits until
**  it has been transmitted. This function doesn't
**  return any value back.
*/
void SpiWriteByte(unsigned char byte)
{
    SPDR = byte;
    //while (!(SPSR & 0x80));
    while(!(SPSR & (1<<SPIF)));
    //byte = SPDR;
}
void SpiWrite2Byte(unsigned char data1, unsigned char data2 )
{
    SPDR = data1;

    while(!(SPSR & (1<<SPIF)));
    //byte = SPDR;
    SPDR = data2;
    while(!(SPSR & (1<<SPIF)));
}
/*
**  SpiReadByte() first writes a byte (a dummy, since
**  that byte is to generate clock signals to "poll" home
**  the byte from the slave. The function returns the
**  received byte.
*/
unsigned char SpiReadByte(void)
{
    SPDR = 0x00;
    while (!(SPSR & 0x80));
    return SPDR;
}

/*
**  SpiReadDataReg() reads the last byte in the SPI register
**  without any clock signals generated. Could be used
**  as reading the last byte received.
*/
unsigned char SpiReadDataReg(void)
{
    return SPDR;
}

